:mod:`API`
----------------------------

preprocessing
=============
.. automodule:: xmip.preprocessing
   :members:
   :undoc-members:
   :show-inheritance:

postprocessing
==============
.. automodule:: xmip.postprocessing
   :members:
   :undoc-members:
   :show-inheritance:


grids
=====
.. automodule:: xmip.grids
   :members:
   :undoc-members:
   :show-inheritance:

regionmask
==========
.. automodule:: xmip.regionmask
   :members:
   :undoc-members:
   :show-inheritance:

utils
=====
.. automodule:: xmip.utils
   :members:
   :undoc-members:
   :show-inheritance:
